@@ -476,11 +476,11 @@ class Irradiance():
 
     x = x_end - x_start
 
-    tan_delta_1v = (h + b*np.sin(panel_tilt*np.pi/180))/(b * np.cos(panel_tilt*np.pi/180) - d - x)
-    tan_delta_1h = h / x
+    tan_delta_1v = np.arctan((h + b*np.sin(panel_tilt*np.pi/180))/(b * np.cos(panel_tilt*np.pi/180) - d - x))
+    tan_delta_1h =  np.arctan(h / x)
 
-    tan_delta_2v = (h + b*np.sin(panel_tilt*np.pi/180))/(x + b*np.cos(panel_tilt*np.pi/180))
-    tan_delta_2h =  h / (x + d)
+    tan_delta_2v =  np.arctan((h + b*np.sin(panel_tilt*np.pi/180))/(x + b*np.cos(panel_tilt*np.pi/180)))
+    tan_delta_2h =   np.arctan(h / (x + d))
 
     E_diffuse_test_point = data['DHI']*((tan_delta_1h - tan_delta_1v) + (tan_delta_2h + tan_delta_2v)) / (np.pi/2)
 
@@ -492,7 +492,7 @@ class Irradiance():
 
     tany_next = (b*np.sin(panel_tilt*np.pi/180))/(d + b*np.cos(panel_tilt*np.pi/180))
 
-    E_rear_diffuse = data['DHI'] * (panel_tilt*np.pi/180 - tany_next)(np.pi/180)
+    E_rear_diffuse = data['DHI'] * (panel_tilt*np.pi/180 - tany_next)/(np.pi/180)
 
     E_rear = E_rear_diffuse + E_rear_ground
 
