@@ -507,9 +507,8 @@ class PVGIS():
             meta = data["meta"]
 
         except:
-            print(f"Error: {data}")
-            erro = f"Error: {data}"
-            return erro
+            print(f"Error : {data}")
+            return data
 
         self.data = inputs, outputs, meta
         return self.data
